@@ -10,7 +10,7 @@ def format(xlab, ylab, show):
     if show:
         plt.show()
 
-def plot(x, y, xlab='$E$ / V', ylab='$i$ / A', fig=1, show=False):
+def plot(x, y, xlab='$E$ / V', ylab='$i$ / A', mark='-', fig=1, show=False):
     plt.figure(fig)
-    plt.plot(x, y)
+    plt.plot(x, y, mark)
     format(xlab, ylab, show)
